function GmailAccess() {
	// method to call when we're done checking for mail (expects one argument - number of unread messages)
	this.onFinishedLookup = null;

	// polling/connection stuff
	this.giveUpAfter = 10000;
	this.servReq = null;
	this.whenGivenUp = null;

	// encoded username/password combination
	this.base64Auth = '';
}

GmailAccess.prototype =
{

	// open the users inbox in the default browser
    gotoInbox : function (username,password)
    {
		var inboxURL = this.getInboxURL(username, password);

		if (window.widget)
		{
			widget.openURL(inboxURL);
		}
		else
		{
			window.location.href = inboxURL;
		}
	},

	// returns the url for accessing the message xml
	getFeedURL : function()
	{
		return "https://mail.google.com/mail/feed/atom";
	},

	// returns the url for accessing the gmail login page (used to get the user into their email regardless of cookies)
	// todo: think about pre-logging the user in and then using the session info returned to do the final step - if possible!
	getInboxURL : function(emailAddress, password)
	{
    var siteExtension = "mail";

	  // are they using a hosted domain
	  var splitAddress = emailAddress.toLowerCase().split('@');
	  if (splitAddress.length > 1 && splitAddress[1] != "googlemail.com" && splitAddress[1] != "gmail.com") {
	    return "http://mail.google.com/hosted/" + splitAddress[1] + "/";
	  }
	  
		var inboxAddress = "http://mail.google.com/mail/";
		var gmailAddress = "https://www.google.com/accounts/ServiceLoginAuth?service=mail&Email="+emailAddress+"&Passwd="+password+"&continue="+inboxAddress;
		return gmailAddress;
	},

	// start the process of updating the unread count.
	refreshCount : function(username,password)
	{
		debug('refreshing count');

		var atomUrl = this.getFeedURL();

		var base64Converter = new Base64();
		this.base64Auth = base64Converter.encode(username+":"+password);

		var localThis = this;

		this.servReq = new XMLHttpRequest();
		this.servReq.open("GET",atomUrl,true);
		this.servReq.setRequestHeader("Cache-Control", "no-cache");
		this.servReq.setRequestHeader("Authorization", "Basic " + this.base64Auth);
		this.servReq.setRequestHeader("Content-Type", "text/xml");
		this.servReq.onreadystatechange = function(results) {localThis.updateFromFeed(results);};
		this.servReq.send(null);

		// give up after a few seconds
		clearTimeout(this.whenGivenUp);
		this.whenGivenUp = setTimeout(function() {localThis.giveUpLooking();},this.giveUpAfter);
	},

	// called whenever the state of the request object changes
	updateFromFeed : function()
	{
		debug('connect status: state:'+this.servReq.readyState+' status: '+this.servReq.status+' - '+this.servReq.statusText);

		if ((this.servReq.readyState == 4) && (this.servReq.status == 200))
		{
			var mailCount = -1;

			clearTimeout(this.whenGivenUp);
			this.whenGivenUp = null;

			debug('Server response: '+this.servReq.responseText);

			mailCount = this.extractUnreadCount(this.servReq.responseText);

			// make the call back to the MailChecker object
			this.onFinishedLookup(mailCount);
		}
	},

	giveUpLooking : function()
	{
		debug('given up looking!');
		// give up checking
		this.servReq.abort()
		// let MailChecker know that we've given up
		this.onFinishedLookup(-1);
	},
	
    // get email count from xml
    extractUnreadCount : function(feedXML)
    {
		newMails = feedXML.match(/<fullcount>(.*?)<\/fullcount>/ig);
		newMails = newMails[0].replace('<fullcount>','').replace('</fullcount>','');
		newMails = parseInt(newMails);
		debug('newMails : ' + newMails.toString());

		return newMails;
    },

	reset : function()
	{
	}
}
